contexttools.TempoMark
======================

.. abjad-lineage:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark

.. autoclass:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_imprecise
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.quarters_per_minute
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.target_context
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.duration
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.textual_indication
   :noindex:

.. autoattribute:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.units_per_minute
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.detach
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.is_tempo_mark_token
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__add__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__div__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__mul__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.TempoMark.TempoMark.TempoMark.__sub__
   :noindex:
